#include <iostream>
#include "mscui.h"

#include <time.h>	// for time() and localtime()

MSCUDate::MSCUDate()
{
	if( !InitToday )
	{
		M = D = 0;
		Y = 0;
	}
	else
	{
		time_t Time;
		struct tm* TMStruct;
		time(&Time);
		TMStruct = localtime(&Time);
		Y = TMStruct->tm_year;
		D = TMStruct->tm_mday;
		M = TMStruct->tm_mon+1;
		if( FourDigit )	// Fix: Added in version 2
			Y+=1900;
	}
}

void MSCUDate::SetFromString( const string& Src )
{
	int Item=0;
	M=D=0;
	Y=0;
	for( int i=0; i<Src.length(); i++)
	{
		if( Item== 0 && Src[i]>='0' && Src[i]<='9' )
			M = M * 10 + Src[i] - '0';
		else if( Item== 1 && Src[i]>='0' && Src[i]<='9' )
			D = D * 10 + Src[i] - '0';
		else if( Item== 2 && Src[i]>='0' && Src[i]<='9' )
			Y = Y * 10 + Src[i] - '0';
		else if( (Src[i]<'0' || Src[i]>'9') && Src[i]!=' ')
			Item++;
	}
}

const string MSCUDate::GetAsString() const 
{
	char Tmp[11];
	if( FourDigit )
		sprintf( Tmp, "%02d%c%02d%c%04d", M, Sep, D, Sep, Y );
	else
		sprintf( Tmp, "%02d%c%02d%c%02d", M, Sep, D, Sep, Y );
	return( Tmp );
}

void MSCUDate::SaveToFile( ostream& O )
{
	O.write( (char*)&Y, sizeof(Y) );
	O.write( &M, sizeof(M) );
	O.write( &D, sizeof(D) );
}
	// Added in version 2
void MSCUDate::LoadFromFile( istream& O )
{
	O.read( (char*)&Y, sizeof(Y) );
	O.read( &M, sizeof(M) );
	O.read( &D, sizeof(D) );
}
	
int MSCUDate::Compare( const MSCUObject& Src) const 
{
	if( GetType()!=Src.GetType() )
		throw "Invalid type conversion";
	const MSCUDate* pDate = (MSCUDate*)&Src;
	if( Y!=pDate->Y )
		return( Y - pDate->Y );
	if( M != pDate->M )
		return( M - pDate->M );
	return( D - pDate->D );
}
	
MSCUObject* MSCUDate::Clone() const 
{ 
	return( new MSCUDate(*this) ); 
}

bool MSCUDate::InitTodaysDate( bool Mode ) 
{ 
	bool Ret; Ret = InitToday; InitToday=Mode; return( Ret ); 
}
bool MSCUDate::Output4Digits( bool Mode ) 
{ 
	bool Ret; Ret = FourDigit; FourDigit=Mode; return( Ret ); 
}
char MSCUDate::Seperator( char NewSep ) 
{ 
	char Ret; Ret = NewSep; Sep=NewSep; return( Ret ); 
}
int MSCUDate::GetMonth() const
{ 
	return(M); 
}
int MSCUDate::GetDay() const
{ 
	return(D); 
}
int MSCUDate::Year() const
{ 
	return(Y);
}
const char* MSCUDate::GetMonthName() const
{
	static char* Months[]={"","Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
	return( Months[M] );
}

bool MSCUDate::InitToday=true;
bool MSCUDate::FourDigit=true;
char MSCUDate::Sep='-';
